#[non_exhaustive]pub struct ListWorkflowsRequest {
pub parent: String,
pub page_size: i32,
pub page_token: String,
pub filter: String,
pub order_by: String,
/* private fields */
}Expand description
Request for the ListWorkflows method.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.parent: StringRequired. Project and location from which the workflows should be listed. Format: projects/{project}/locations/{location}
page_size: i32Maximum number of workflows to return per call. The service might return fewer than this value even if not at the end of the collection. If a value is not specified, a default value of 500 is used. The maximum permitted value is 1000 and values greater than 1000 are coerced down to 1000.
page_token: StringA page token, received from a previous ListWorkflows call.
Provide this to retrieve the subsequent page.
When paginating, all other parameters provided to ListWorkflows must
match the call that provided the page token.
filter: StringFilter to restrict results to specific workflows. For details, see <a href=“https://google.aip.dev/160” class=“external”>AIP-160.
For example, if you are using the Google APIs Explorer:
state="SUCCEEDED"
or
createTime>"2023-08-01" AND state="FAILED"
order_by: StringComma-separated list of fields that specify the order of the results. Default sorting order for a field is ascending. To specify descending order for a field, append a “desc” suffix. If not specified, the results are returned in an unspecified order.
Implementations
Sourceimpl ListWorkflowsRequest
impl ListWorkflowsRequest
Sourcepub fn set_parent<T: Into<String>>(self, v: T) -> Self
pub fn set_parent<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_page_size<T: Into<i32>>(self, v: T) -> Self
pub fn set_page_size<T: Into<i32>>(self, v: T) -> Self
Sourcepub fn set_page_token<T: Into<String>>(self, v: T) -> Self
pub fn set_page_token<T: Into<String>>(self, v: T) -> Self
Sets the value of page_token.
Example
let x = ListWorkflowsRequest::new().set_page_token("example");Sourcepub fn set_filter<T: Into<String>>(self, v: T) -> Self
pub fn set_filter<T: Into<String>>(self, v: T) -> Self